Method: OpenapiClient::ConnectOntracRequestBody#initialize
- Defined in:
- lib/openapi_client/models/connect_ontrac_request_body.rb
#initialize(attributes = {}) ⇒ ConnectOntracRequestBody
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/openapi_client/models/connect_ontrac_request_body.rb', line 53 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OpenapiClient::ConnectOntracRequestBody` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OpenapiClient::ConnectOntracRequestBody`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'nickname') self.nickname = attributes[:'nickname'] end if attributes.key?(:'account_number') self.account_number = attributes[:'account_number'] end if attributes.key?(:'password') self.password = attributes[:'password'] end end |